coo.oscillo and coo.oscillo1 compute and provide standardized plot when given a matrix of coordinates or a vector, respectively.coo.oscillo(coo, method = c("d0", "di")[1], plot = TRUE, rug = TRUE,
legend = TRUE, cols = col.gallus(2), ...)
coo.oscillo1(coo, method = c("d0", "di")[1], plot = TRUE, rug = TRUE,
legend = TRUE, cols = col.gallus(1),
xlab = "Points sampled along the outline", ylab = "Deviation", ...)character. Whether to calculate differences with the first point ("d0") or the previous ("di"), ie the derivate.logical. Whether to display a pseudo rug, that indicate if the derivate is positive.logical. Whether to add a legend.vector of two (for coo.oscillo) or a single (coo.oscillo1) color for lines.character. Alternate label for x-axis.character. Alternate label for y-axis.list with two or one component(s), giving the difference calculated.data(bot)
coo.oscillo(bot@coo[[1]], lty=2)
coo.oscillo1(tfourier(bot@coo[[1]])$phi)Run the code above in your browser using DataLab