Nef-object, and two positions on the set defined by $PC_1$ and $PC_2$, calculates and plots deformation grids, "vector field" or iso-deformation lines between these two shapes.tps.grid(Nef, fr, to, nb.pts = 50, amp = 1, grid.size = 50,
grid.col = "grey40", cont = TRUE,
cont.col = c("dodgerblue3", "firebrick3"), cont.lwd = rep(3,2))
tps.iso(Nef, fr, to, nb.pts = 200, amp = 1, iso.pts = 1000,
col.pal = topo.colors, col.lev = 500,
cont.to = TRUE, cont.fr = TRUE, cont.lev = 10,
cont.col = c("dodgerblue3", "firebrick3"), cont.lwd = rep(3,2))
tps.vf(Nef, fr, to, nb.pts = 100, amp = 1, arr.nb = 300,
arr.len = 0.05, arr.ang = 30, arr.col = "grey40",
arr.pal = FALSE, arr.palette = topo.colors, arr.pal.lev = 20,
arr.lwd = 1, cont.col = c("dodgerblue3", "firebrick3"),
cont.lwd = rep(3, 2))Nef objectnumerics indicating the $(x; y)$ coordinates of the starting point. If not provided, locator(1) is callednumerics indicating the $(x; y)$ coordinates of the ending point. If not provided, locator(1) is calledinteger indicating the number of points used to calculate deformation gridsnumeric indicating magnifying factor for deformationslogical indicating whether to plot original and deformed shapeslogical indicating whether to plot the original shapelogical indicating whether to plot the deformed shapeinteger or character indicating the col of the two outlines comparednumeric indicating a vector containing the lwd of the two outlines comparednumeric indicating deformation grid sizeinteger indicating the number of iso points to use for isolines calculationrainbow, heat.colors or such as build by colorRampPalette for isolines drawinginteger indicating how many color levels to useinteger indicating how many isolines to calculateinteger indicating how many arrows to displaynumeric indicating the arrows lengthnumeric indicating the arrows angleinteger or a character indicating the arrows colorlogical indicating whether to use or not a color palette for drawing arrowsrainbow, heat.colors or such as build by colorRampPaletteinteger specifying how many levels to use for the color palettenumeric indicating the arrows lwddata(bottles.nef)
tps.grid(bottles.nef, fr=c(-0.05, -0.05), to=c(0.15, 0.05))
tps.vf(bottles.nef, fr=c(-0.05, -0.05), to=c(0.15, 0.05))
tps.iso(bottles.nef, fr=c(-0.05, -0.05), to=c(0.15, 0.05))Run the code above in your browser using DataLab